mercurial/filemerge.py
branchstable
changeset 16254 c7eef052c9e3
parent 16205 b605448eb254
child 16256 c655e4acaa82
--- a/mercurial/filemerge.py	Mon Mar 12 17:02:45 2012 -0300
+++ b/mercurial/filemerge.py	Tue Mar 13 15:12:26 2012 -0500
@@ -97,8 +97,11 @@
         if check(t, None, symlink, binary):
             toolpath = _findtool(ui, t)
             return (t, '"' + toolpath + '"')
-    # internal merge as last resort
-    return (not (symlink or binary) and "internal:merge" or None, None)
+
+    # internal merge or prompt as last resort
+    if symlink or binary:
+        return "internal:prompt", None
+    return "internal:merge", None
 
 def _eoltype(data):
     "Guess the EOL type of a file"